
/*
 * help strings
 */

#define help_text1 "  Messages and action keys:\n"\
	"  e) Toggle envelope reading for from/to\n"\
	"  d) Delete message\n"\
	"  h) Hold message\n"\
	"  r) Requeue message\n"\
	"  l) Release message in 'hold' queue\n"\
	"  m) Mark message as tag block start\n"\
	"  t) Tag/Untag message (up to mark if present)\n"\
	"  a) Tag all messages\n"\
	"  u) Untag all messages\n"\
	"  ;) Make actions work on tagged messages\n"\
	"  :) Toggle auto-work-on-tagged\n"\
	"  s) Show selected message\n"\
	"  /) Search in From: or To: headers\n"\
	"  n) Search next\n"\
	"  p) Search previous\n"\
	"  T) Search and tag messages\n"\
	"  c) Toggle confirmation request\n"\
	"  -) Suspend/resume queue scanning\n"\
	"  +) Toggle colors on/off\n"\
	"  ?) This help\n"\
	"  q) Quit\n"

#define help_text2 "  In the windows, you can use G/END, g/HOME, PgUP/DN keys\n"\
	"  To change current queue:\n"\
	"  1) Deferred queue\n"\
	"  2) Active queue\n"\
	"  3) Incoming queue\n"\
	"  4) Hold queue\n"\
	"  >) Increase body window height\n"\
	"  <) Decrease body window height\n"\
	"  ,) Scroll body window up\n"\
	"  .) Scroll body window down\n"
